Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Queue ¶
type Queue[T any] struct { // Items added to the queue are sent to this channel as they become due. // If the number of items that will be added to the queue exceeds the buffer // size, this channel must be continously read in order to prevent blocking. C <-chan T // contains filtered or unexported fields }
func New ¶
Create a new Queue that will run until the provided context is cancelled. The second argument specifies the buffer size of C, the outgoing channel.
Click to show internal directories.
Click to hide internal directories.